Method: GraphQL::Dataloader#set_fiber_variables

Defined in:
lib/graphql/dataloader.rb

#set_fiber_variables(vars) ⇒ void

This method returns an undefined value.

Set up the fiber variables in a new fiber.

This is called within the fiber, right after it is spawned.

Parameters:



95
96
97
98
# File 'lib/graphql/dataloader.rb', line 95

def set_fiber_variables(vars)
  vars.each { |k, v| Thread.current[k] = v }
  nil
end