Method: GraphQL::Execution::Lookahead#selected?

Defined in:
lib/graphql/execution/lookahead.rb

#selected?Boolean

Returns True if this lookahead represents a field that was requested.

Returns:

  • (Boolean)

    True if this lookahead represents a field that was requested



107
108
109
# File 'lib/graphql/execution/lookahead.rb', line 107

def selected?
  true
end