Method: GraphQL::Field#lazy_resolve
- Defined in:
- lib/graphql/field.rb
#lazy_resolve(obj, args, ctx) ⇒ Object
If #resolve returned and object which should be handled lazily, this method will be called later force the object to return its value.
297 298 299 |
# File 'lib/graphql/field.rb', line 297 def lazy_resolve(obj, args, ctx) @lazy_resolve_proc.call(obj, args, ctx) end |