Method: GraphQL::Field#property

Defined in:
lib/graphql/field.rb

#propertySymbol?

Returns The method to call on obj to return this field (overrides #name if present).

Returns:

  • (Symbol, nil)

    The method to call on obj to return this field (overrides #name if present)



177
178
179
# File 'lib/graphql/field.rb', line 177

def property
  @property
end