Method: GraphQL::Field#trace

Defined in:
lib/graphql/field.rb

#traceBoolean

Returns True if this field should be traced. By default, fields are only traced if they are not a ScalarType or EnumType.

Returns:

  • (Boolean)

    True if this field should be traced. By default, fields are only traced if they are not a ScalarType or EnumType.



194
195
196
# File 'lib/graphql/field.rb', line 194

def trace
  @trace
end