Method: GraphQL::Pagination::Connection#arguments

Defined in:
lib/graphql/pagination/connection.rb

#argumentsHash<Symbol => Object>

Returns The field arguments from the field that returned this connection.

Returns:

  • (Hash<Symbol => Object>)

    The field arguments from the field that returned this connection



57
58
59
# File 'lib/graphql/pagination/connection.rb', line 57

def arguments
  @arguments
end