Method: GraphQL::Pagination::Connection#has_next_page

Defined in:
lib/graphql/pagination/connection.rb

#has_next_pageBoolean

Returns True if there are more items after this page.

Returns:

  • (Boolean)

    True if there are more items after this page

Raises:



196
197
198
# File 'lib/graphql/pagination/connection.rb', line 196

def has_next_page
  raise PaginationImplementationMissingError, "Implement #{self.class}#has_next_page to return the next-page check"
end