Method: GraphQL::Pagination::Connection#items

Defined in:
lib/graphql/pagination/connection.rb

#itemsObject (readonly)

Returns A list object, from the application. This is the unpaginated value passed into the connection.

Returns:

  • (Object)

    A list object, from the application. This is the unpaginated value passed into the connection.



19
20
21
# File 'lib/graphql/pagination/connection.rb', line 19

def items
  @items
end