Method: GraphQL::Query::ValidationPipeline#valid?

Defined in:
lib/graphql/query/validation_pipeline.rb

#valid?Boolean

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns does this query have errors that should prevent it from running?.

Returns:

  • (Boolean)

    does this query have errors that should prevent it from running?



32
33
34
35
# File 'lib/graphql/query/validation_pipeline.rb', line 32

def valid?
  ensure_has_validated
  @valid
end