Method: GraphQL::Query#initialize

Defined in:
lib/graphql/query.rb

#initialize(schema, query_string = nil, query: nil, document: nil, context: nil, variables: nil, multiplex: nil, validate: true, static_validator: nil, visibility_profile: nil, subscription_topic: nil, operation_name: nil, root_value: nil, max_depth: schema.max_depth, max_complexity: schema.max_complexity, warden: nil, use_visibility_profile: nil) ⇒ Query

Prepare query query_string on schema

Parameters:

  • schema (GraphQL::Schema)
  • query_string (String) (defaults to: nil)
  • context (#[]) (defaults to: nil)

    an arbitrary hash of values which you can access in Field#resolve

  • variables (Hash) (defaults to: nil)

    values for $variables in the query

  • operation_name (String) (defaults to: nil)

    if the query string contains many operations, this is the one which should be executed

  • root_value (Object) (defaults to: nil)

    the object used to resolve fields on the root type

  • max_depth (Numeric) (defaults to: schema.max_depth)

    the maximum number of nested selections allowed for this query (falls back to schema-level value)

  • max_complexity (Numeric) (defaults to: schema.max_complexity)

    the maximum field complexity for this query (falls back to schema-level value)

  • visibility_profile (Symbol) (defaults to: nil)

    Another way to assign context[:visibility_profile]



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/graphql/query.rb', line 136

def initialize(schema, query_string = nil, query: nil, document: nil, context: nil, variables: nil, multiplex: nil, validate: true, static_validator: nil, visibility_profile: nil, subscription_topic: nil, operation_name: nil, root_value: nil, max_depth: schema.max_depth, max_complexity: schema.max_complexity, warden: nil, use_visibility_profile: nil)
  # Even if `variables: nil` is passed, use an empty hash for simpler logic
  variables ||= {}
  @multiplex = multiplex
  @schema = schema
  @context = schema.context_class.new(query: self, values: context)
  if visibility_profile
    @context[:visibility_profile] ||= visibility_profile
  end

  if use_visibility_profile.nil?
    use_visibility_profile = warden ? false : schema.use_visibility_profile?
  end

  if use_visibility_profile
    @visibility_profile = @schema.visibility.profile_for(@context)
    @warden = Schema::Warden::NullWarden.new(context: @context, schema: @schema)
  else
    @visibility_profile = nil
    @warden = warden
  end

  @subscription_topic = subscription_topic
  @root_value = root_value
  @fragments = nil
  @operations = nil
  @validate = validate
  self.static_validator = static_validator if static_validator
  context_tracers = (context ? context.fetch(:tracers, []) : [])
  @tracers = schema.tracers + context_tracers

  if !context_tracers.empty? && !(schema.trace_class <= GraphQL::Tracing::CallLegacyTracers)
    raise ArgumentError, "context[:tracers] are not supported without `trace_with(GraphQL::Tracing::CallLegacyTracers)` in the schema configuration, please add it."
  end

  @analysis_errors = []
  if variables.is_a?(String)
    raise ArgumentError, "Query variables should be a Hash, not a String. Try JSON.parse to prepare variables."
  else
    @provided_variables = variables || {}
  end

  @query_string = query_string || query
  @document = document

  if @query_string && @document
    raise ArgumentError, "Query should only be provided a query string or a document, not both."
  end

  if @query_string && !@query_string.is_a?(String)
    raise ArgumentError, "Query string argument should be a String, got #{@query_string.class.name} instead."
  end

  # A two-layer cache of type resolution:
  # { abstract_type => { value => resolved_type } }
  @resolved_types_cache = Hash.new do |h1, k1|
    h1[k1] = Hash.new do |h2, k2|
      h2[k2] = @schema.resolve_type(k1, k2, @context)
    end
  end

  # Trying to execute a document
  # with no operations returns an empty hash
  @ast_variables = []
  @mutation = false
  @operation_name = operation_name
  @prepared_ast = false
  @validation_pipeline = nil
  @max_depth = max_depth
  @max_complexity = max_complexity

  @result_values = nil
  @executed = false

  @logger = schema.logger_for(context)
end