Method: GraphQL::Query#operation_name

Defined in:
lib/graphql/query.rb

#operation_namenil, String

Returns The operation name provided by client or the one inferred from the document. Used to determine which operation to run.

Returns:

  • (nil, String)

    The operation name provided by client or the one inferred from the document. Used to determine which operation to run.



71
72
73
# File 'lib/graphql/query.rb', line 71

def operation_name
  @operation_name
end