7
8
9
10
11
12
|
# File 'lib/graphql/schema/field/connection_extension.rb', line 7
def apply
field.argument :after, "String", "Returns the elements in the list that come after the specified cursor.", required: false
field.argument :before, "String", "Returns the elements in the list that come before the specified cursor.", required: false
field.argument :first, "Int", "Returns the first _n_ elements from the list.", required: false
field.argument :last, "Int", "Returns the last _n_ elements from the list.", required: false
end
|