Method: GraphQL::Schema::Field#method_sym

Defined in:
lib/graphql/schema/field.rb

#method_symSymbol (readonly)

Returns Method or hash key on the underlying object to look up.

Returns:

  • (Symbol)

    Method or hash key on the underlying object to look up



27
28
29
# File 'lib/graphql/schema/field.rb', line 27

def method_sym
  @method_sym
end