Method: GraphQL::Schema::Field#original_name

Defined in:
lib/graphql/schema/field.rb

#original_nameSymbol (readonly)

Returns the original name of the field, passed in by the user.

Returns:

  • (Symbol)

    the original name of the field, passed in by the user



85
86
87
# File 'lib/graphql/schema/field.rb', line 85

def original_name
  @original_name
end