Method: GraphQL::Schema::FieldExtension#apply
- Defined in:
- lib/graphql/schema/field_extension.rb
#apply ⇒ void
This method returns an undefined value.
Called when this extension is attached to a field. The field definition may be extended during this method.
82 83 |
# File 'lib/graphql/schema/field_extension.rb', line 82 def apply end |