Method: GraphQL::Schema::Member::BaseDSLMethods#introspection

Defined in:
lib/graphql/schema/member/base_dsl_methods.rb

#introspection(new_introspection = nil) ⇒ Boolean

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns If true, this object is part of the introspection system.

Returns:

  • (Boolean)

    If true, this object is part of the introspection system



86
87
88
89
90
91
92
93
94
# File 'lib/graphql/schema/member/base_dsl_methods.rb', line 86

def introspection(new_introspection = nil)
  if !new_introspection.nil?
    @introspection = new_introspection
  elsif defined?(@introspection)
    @introspection
  else
    false
  end
end