Method: GraphQL::Schema::Member::HasFields::ObjectMethods#fields

Defined in:
lib/graphql/schema/member/has_fields.rb

#fields(context = GraphQL::Query::NullContext.instance) ⇒ Hash<String => GraphQL::Schema::Field>

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns Fields on this object, keyed by name, including inherited fields.

Returns:

  • (Hash<String => GraphQL::Schema::Field>)

    Fields on this object, keyed by name, including inherited fields



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/graphql/schema/member/has_fields.rb', line 237

def fields(context = GraphQL::Query::NullContext.instance)
  # Objects need to check that the interface implementation is visible, too
  warden = Warden.from_context(context)
  # Local overrides take precedence over inherited fields
  visible_fields = {}
  had_any_fields_at_all = false
  for ancestor in ancestors
    if ancestor.respond_to?(:own_fields) && visible_interface_implementation?(ancestor, context, warden)
      ancestor.own_fields.each do |field_name, fields_entry|
        had_any_fields_at_all = true
        # Choose the most local definition that passes `.visible?` --
        # stop checking for fields by name once one has been found.
        if !visible_fields.key?(field_name) && (f = Warden.visible_entry?(:visible_field?, fields_entry, context, warden))
          visible_fields[field_name] = f.ensure_loaded
        end
      end
    end
  end
  if !had_any_fields_at_all && !has_no_fields?
    warn(GraphQL::Schema::Object::FieldsAreRequiredError.new(self).message + "\n\nThis will raise an error in a future GraphQL-Ruby version.")
  end
  visible_fields
end