Method: GraphQL::Schema::Warden#loadable_possible_types

Defined in:
lib/graphql/schema/warden.rb

#loadable_possible_types(abstract_type, _ctx) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

This abstract type was determined to be used for loads only. All its possible types are valid possibilities here -- no filtering.



242
243
244
245
246
247
248
249
250
251
# File 'lib/graphql/schema/warden.rb', line 242

def loadable_possible_types(abstract_type, _ctx)
  @loadable_possible_types ||= read_through do |t|
    if t.is_a?(Class) # union
      t.possible_types
    else
      @schema.possible_types(abstract_type)
    end
  end
  @loadable_possible_types[abstract_type]
end