Method: GraphQL::Schema::Warden#visible_field?
- Defined in:
- lib/graphql/schema/warden.rb
#visible_field?(field_defn, _ctx = nil, owner = field_defn.owner) ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
375 376 377 378 379 380 381 382 383 |
# File 'lib/graphql/schema/warden.rb', line 375 def visible_field?(field_defn, _ctx = nil, owner = field_defn.owner) # This field is visible in its own right visible?(field_defn) && # This field's return type is visible visible_and_reachable_type?(field_defn.type.unwrap) && # This field is either defined on this object type, # or the interface it's inherited from is also visible ((field_defn.respond_to?(:owner) && field_defn.owner == owner) || field_on_visible_interface?(field_defn, owner)) end |