Method: GraphQL::StaticValidation::BaseVisitor#path

Defined in:
lib/graphql/static_validation/base_visitor.rb

#pathArray<String>

Returns The nesting of the current position in the AST.

Returns:

  • (Array<String>)

    The nesting of the current position in the AST



24
25
26
# File 'lib/graphql/static_validation/base_visitor.rb', line 24

def path
  @path.dup
end