Class: GraphQL::Execution::Interpreter::Runtime::GraphQLResultArray Private

Inherits:
Object
  • Object
show all
Includes:
GraphQLResult
Defined in:
lib/graphql/execution/interpreter/runtime.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

API:

  • private

Instance Attribute Summary

Attributes included from GraphQLResult

#graphql_dead, #graphql_is_non_null_in_parent, #graphql_parent, #graphql_result_data, #graphql_result_name

Instance Method Summary collapse

Methods included from GraphQLResult

#build_path, #path

Constructor Details

#initialize(_result_name, _parent_result, _is_non_null_in_parent) ⇒ GraphQLResultArray

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of GraphQLResultArray.

API:

  • private



141
142
143
144
# File 'lib/graphql/execution/interpreter/runtime.rb', line 141

def initialize(_result_name, _parent_result, _is_non_null_in_parent)
  super
  @graphql_result_data = []
end

Instance Method Details

#graphql_skip_at(index) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/graphql/execution/interpreter/runtime.rb', line 146

def graphql_skip_at(index)
  # Mark this index as dead. It's tricky because some indices may already be storing
  # `Lazy`s. So the runtime is still holding indexes _before_ skipping,
  # this object has to coordinate incoming writes to account for any already-skipped indices.
  @skip_indices ||= []
  @skip_indices << index
  offset_by = @skip_indices.count { |skipped_idx| skipped_idx < index}
  delete_at_index = index - offset_by
   && .delete_at(delete_at_index)
  @graphql_result_data.delete_at(delete_at_index)
end

#set_child_result(idx, value) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



168
169
170
171
172
173
174
175
176
177
178
# File 'lib/graphql/execution/interpreter/runtime.rb', line 168

def set_child_result(idx, value)
  if @skip_indices
    offset_by = @skip_indices.count { |skipped_idx| skipped_idx < idx }
    idx -= offset_by
  end
  @graphql_result_data[idx] = value.graphql_result_data
  # If we encounter some part of this response that requires metadata tracking,
  # then create the metadata hash if necessary. It will be kept up-to-date after this.
  ( ||= @graphql_result_data.dup)[idx] = value
  value
end

#set_leaf(idx, value) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



158
159
160
161
162
163
164
165
166
# File 'lib/graphql/execution/interpreter/runtime.rb', line 158

def set_leaf(idx, value)
  if @skip_indices
    offset_by = @skip_indices.count { |skipped_idx| skipped_idx < idx }
    idx -= offset_by
  end
  @graphql_result_data[idx] = value
   && [idx] = value
  value
end

#valuesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



180
181
182
# File 'lib/graphql/execution/interpreter/runtime.rb', line 180

def values
  ( || @graphql_result_data)
end