Class: GraphQL::Query
- Inherits:
-
Object
- Object
- GraphQL::Query
- Defined in:
- lib/graphql/query.rb,
lib/graphql/query/context.rb,
lib/graphql/query/executor.rb,
lib/graphql/query/arguments.rb,
lib/graphql/query/variables.rb,
lib/graphql/query/literal_input.rb,
lib/graphql/query/serial_execution.rb,
lib/graphql/query/input_validation_result.rb,
lib/graphql/query/variable_validation_error.rb,
lib/graphql/query/serial_execution/field_resolution.rb,
lib/graphql/query/serial_execution/value_resolution.rb,
lib/graphql/query/serial_execution/execution_context.rb,
lib/graphql/query/serial_execution/operation_resolution.rb,
lib/graphql/query/serial_execution/selection_resolution.rb
Overview
Defined Under Namespace
Classes: Arguments, Context, Executor, InputValidationResult, LiteralInput, OperationNameMissingError, SerialExecution, VariableValidationError, Variables
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
Returns the value of attribute context.
-
#document ⇒ Object
readonly
Returns the value of attribute document.
-
#fragments ⇒ Object
readonly
Returns the value of attribute fragments.
-
#max_depth ⇒ Object
readonly
Returns the value of attribute max_depth.
-
#operations ⇒ Object
readonly
Returns the value of attribute operations.
-
#query_string ⇒ Object
readonly
Returns the value of attribute query_string.
-
#root_value ⇒ Object
readonly
Returns the value of attribute root_value.
-
#schema ⇒ Object
readonly
Returns the value of attribute schema.
Instance Method Summary collapse
-
#arguments_for(irep_node, definition) ⇒ GraphQL::Query::Arguments
Node-level cache for calculating arguments.
-
#initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, validate: true, operation_name: nil, root_value: nil, max_depth: nil, max_complexity: nil) ⇒ Query
constructor
Prepare query
query_stringonschema. - #internal_representation ⇒ Object
-
#result ⇒ Object
Get the result for this query, executing it once.
-
#selected_operation ⇒ GraphQL::Language::Nodes::OperationDefinition?
This is the operation to run for this query.
- #validation_errors ⇒ Object
-
#variables ⇒ GraphQL::Query::Variables
Determine the values for variables of this query, using default values if a value isn't provided at runtime.
Constructor Details
#initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, validate: true, operation_name: nil, root_value: nil, max_depth: nil, max_complexity: nil) ⇒ Query
Prepare query query_string on schema
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/graphql/query.rb', line 32 def initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, validate: true, operation_name: nil, root_value: nil, max_depth: nil, max_complexity: nil) fail ArgumentError, "a query string or document is required" unless query_string || document @schema = schema @max_depth = max_depth || schema.max_depth @max_complexity = max_complexity || schema.max_complexity @query_analyzers = schema.query_analyzers.dup if @max_depth @query_analyzers << GraphQL::Analysis::MaxQueryDepth.new(@max_depth) end if @max_complexity @query_analyzers << GraphQL::Analysis::MaxQueryComplexity.new(@max_complexity) end @context = Context.new(query: self, values: context) @root_value = root_value @validate = validate @operation_name = operation_name @fragments = {} @operations = {} @provided_variables = variables @query_string = query_string @document = document || GraphQL.parse(query_string) @document.definitions.each do |part| if part.is_a?(GraphQL::Language::Nodes::FragmentDefinition) @fragments[part.name] = part elsif part.is_a?(GraphQL::Language::Nodes::OperationDefinition) @operations[part.name] = part else raise GraphQL::ExecutionError, "GraphQL query cannot contain a schema definition" end end @arguments_cache = Hash.new { |h, k| h[k] = {} } end |
Instance Attribute Details
#context ⇒ Object (readonly)
Returns the value of attribute context.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def context @context end |
#document ⇒ Object (readonly)
Returns the value of attribute document.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def document @document end |
#fragments ⇒ Object (readonly)
Returns the value of attribute fragments.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def fragments @fragments end |
#max_depth ⇒ Object (readonly)
Returns the value of attribute max_depth.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def max_depth @max_depth end |
#operations ⇒ Object (readonly)
Returns the value of attribute operations.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def operations @operations end |
#query_string ⇒ Object (readonly)
Returns the value of attribute query_string.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def query_string @query_string end |
#root_value ⇒ Object (readonly)
Returns the value of attribute root_value.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def root_value @root_value end |
#schema ⇒ Object (readonly)
Returns the value of attribute schema.
20 21 22 |
# File 'lib/graphql/query.rb', line 20 def schema @schema end |
Instance Method Details
#arguments_for(irep_node, definition) ⇒ GraphQL::Query::Arguments
Node-level cache for calculating arguments. Used during execution and query analysis.
120 121 122 123 124 125 126 127 128 |
# File 'lib/graphql/query.rb', line 120 def arguments_for(irep_node, definition) @arguments_cache[irep_node][definition] ||= begin GraphQL::Query::LiteralInput.from_arguments( irep_node.ast_node.arguments, definition.arguments, self.variables ) end end |
#internal_representation ⇒ Object
104 105 106 107 108 109 |
# File 'lib/graphql/query.rb', line 104 def internal_representation @internal_representation ||= begin perform_validation @internal_representation end end |
#result ⇒ Object
Get the result for this query, executing it once
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/graphql/query.rb', line 69 def result @result ||= begin if @validate && (validation_errors.any? || analysis_errors.any?) { "errors" => validation_errors + analysis_errors} else Executor.new(self).result end end end |
#selected_operation ⇒ GraphQL::Language::Nodes::OperationDefinition?
This is the operation to run for this query. If more than one operation is present, it must be named at runtime.
84 85 86 87 88 89 |
# File 'lib/graphql/query.rb', line 84 def selected_operation @selected_operation ||= begin perform_validation @selected_operation end end |
#validation_errors ⇒ Object
111 112 113 114 115 116 |
# File 'lib/graphql/query.rb', line 111 def validation_errors @validation_errors ||= begin perform_validation @validation_errors end end |
#variables ⇒ GraphQL::Query::Variables
Determine the values for variables of this query, using default values if a value isn't provided at runtime.
Raises if a non-null variable isn't provided at runtime.
96 97 98 99 100 101 102 |
# File 'lib/graphql/query.rb', line 96 def variables @variables ||= GraphQL::Query::Variables.new( schema, selected_operation.variables, @provided_variables ) end |