Method: GraphQL::Query#initialize

Defined in:
lib/graphql/query.rb

#initialize(schema, query_string = nil, query: nil, document: nil, context: nil, variables: nil, validate: true, static_validator: nil, subscription_topic: nil, operation_name: nil, root_value: nil, max_depth: schema.max_depth, max_complexity: schema.max_complexity, warden: nil) ⇒ Query

Prepare query query_string on schema

Parameters:

  • schema (GraphQL::Schema)
  • query_string (String) (defaults to: nil)
  • context (#[]) (defaults to: nil)

    an arbitrary hash of values which you can access in Field#resolve

  • variables (Hash) (defaults to: nil)

    values for $variables in the query

  • operation_name (String) (defaults to: nil)

    if the query string contains many operations, this is the one which should be executed

  • root_value (Object) (defaults to: nil)

    the object used to resolve fields on the root type

  • max_depth (Numeric) (defaults to: schema.max_depth)

    the maximum number of nested selections allowed for this query (falls back to schema-level value)

  • max_complexity (Numeric) (defaults to: schema.max_complexity)

    the maximum field complexity for this query (falls back to schema-level value)



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/graphql/query.rb', line 98

def initialize(schema, query_string = nil, query: nil, document: nil, context: nil, variables: nil, validate: true, static_validator: nil, subscription_topic: nil, operation_name: nil, root_value: nil, max_depth: schema.max_depth, max_complexity: schema.max_complexity, warden: nil)
  # Even if `variables: nil` is passed, use an empty hash for simpler logic
  variables ||= {}
  @schema = schema
  @context = schema.context_class.new(query: self, object: root_value, values: context)
  @warden = warden
  @subscription_topic = subscription_topic
  @root_value = root_value
  @fragments = nil
  @operations = nil
  @validate = validate
  self.static_validator = static_validator if static_validator
  context_tracers = (context ? context.fetch(:tracers, []) : [])
  @tracers = schema.tracers + context_tracers

  # Support `ctx[:backtrace] = true` for wrapping backtraces
  if context && context[:backtrace] && !@tracers.include?(GraphQL::Backtrace::Tracer)
    if schema.trace_class <= GraphQL::Tracing::CallLegacyTracers
      context_tracers += [GraphQL::Backtrace::Tracer]
      @tracers << GraphQL::Backtrace::Tracer
    elsif !(current_trace.class <= GraphQL::Backtrace::Trace)
      raise "Invariant: `backtrace: true` should have provided a trace class with Backtrace mixed in, but it didnt. (Found: #{current_trace.class.ancestors}). This is a bug in GraphQL-Ruby, please report it on GitHub."
    end
  end

  if context_tracers.any? && !(schema.trace_class <= GraphQL::Tracing::CallLegacyTracers)
    raise ArgumentError, "context[:tracers] are not supported without `trace_with(GraphQL::Tracing::CallLegacyTracers)` in the schema configuration, please add it."
  end

  @analysis_errors = []
  if variables.is_a?(String)
    raise ArgumentError, "Query variables should be a Hash, not a String. Try JSON.parse to prepare variables."
  else
    @provided_variables = variables || {}
  end

  @query_string = query_string || query
  @document = document

  if @query_string && @document
    raise ArgumentError, "Query should only be provided a query string or a document, not both."
  end

  if @query_string && !@query_string.is_a?(String)
    raise ArgumentError, "Query string argument should be a String, got #{@query_string.class.name} instead."
  end

  # A two-layer cache of type resolution:
  # { abstract_type => { value => resolved_type } }
  @resolved_types_cache = Hash.new do |h1, k1|
    h1[k1] = Hash.new do |h2, k2|
      h2[k2] = @schema.resolve_type(k1, k2, @context)
    end
  end

  # Trying to execute a document
  # with no operations returns an empty hash
  @ast_variables = []
  @mutation = false
  @operation_name = operation_name
  @prepared_ast = false
  @validation_pipeline = nil
  @max_depth = max_depth
  @max_complexity = max_complexity

  @result_values = nil
  @executed = false
end