A function to call when execute receives an invalid query string
The default is to add the error to context.errors
context.errors
Parameters:
The error encountered during parsing
The context for the query where the error occurred
Returns:
void
1357 1358 1359
# File 'lib/graphql/schema.rb', line 1357 def parse_error(parse_err, ctx) ctx.errors.push(parse_err) end