Exception: GraphQL::Schema::Resolver::LoadApplicationObjectFailedError

Inherits:
ExecutionError
  • Object
show all
Defined in:
lib/graphql/schema/resolver.rb

Instance Attribute Summary collapse

Attributes inherited from ExecutionError

#ast_node, #extensions, #options, #path

Instance Method Summary collapse

Methods inherited from ExecutionError

#to_h

Constructor Details

#initialize(argument:, id:, object:) ⇒ LoadApplicationObjectFailedError

Returns a new instance of LoadApplicationObjectFailedError.



172
173
174
175
176
177
# File 'lib/graphql/schema/resolver.rb', line 172

def initialize(argument:, id:, object:)
  @id = id
  @argument = argument
  @object = object
  super("No object found for `#{argument.graphql_name}: #{id.inspect}`")
end

Instance Attribute Details

#argument ⇒ GraphQL::Schema::Argument (readonly)

Returns the argument definition for the argument that was looked up.

Returns:

  • the argument definition for the argument that was looked up



167
168
169
# File 'lib/graphql/schema/resolver.rb', line 167

def argument
  @argument
end

#id ⇒ String (readonly)

Returns The ID provided by the client.

Returns:

  • The ID provided by the client



169
170
171
# File 'lib/graphql/schema/resolver.rb', line 169

def id
  @id
end

#object ⇒ Object (readonly)

Returns The value found with this ID.

Returns:

  • The value found with this ID



171
172
173
# File 'lib/graphql/schema/resolver.rb', line 171

def object
  @object
end