Method: GraphQL::Dataloader::Source#result_key_for
- Defined in:
- lib/graphql/dataloader/source.rb
#result_key_for(value) ⇒ Object
Implement this method to return a stable identifier if different key objects should load the same data value.
34 35 36 |
# File 'lib/graphql/dataloader/source.rb', line 34 def result_key_for(value) value end |