Method: GraphQL::Dataloader#cleanup_fiber
- Defined in:
- lib/graphql/dataloader.rb
#cleanup_fiber ⇒ Object
This method is called when Dataloader is finished using a fiber. Use it to perform any cleanup, such as releasing database connections (if required manually)
102 103 |
# File 'lib/graphql/dataloader.rb', line 102 def cleanup_fiber end |