Method: GraphQL::Execution::Interpreter::Arguments#merge_extras
- Defined in:
- lib/graphql/execution/interpreter/arguments.rb
#merge_extras(extra_args) ⇒ Interpreter::Arguments
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Create a new arguments instance which includes these extras.
This is called by the runtime to implement field extras: [...]
76 77 78 79 80 81 |
# File 'lib/graphql/execution/interpreter/arguments.rb', line 76 def merge_extras(extra_args) self.class.new( argument_values: argument_values, keyword_arguments: keyword_arguments.merge(extra_args) ) end |