Method: GraphQL::Query#selected_operation
- Defined in:
- lib/graphql/query.rb
#selected_operation ⇒ GraphQL::Language::Nodes::OperationDefinition?
This is the operation to run for this query. If more than one operation is present, it must be named at runtime.
297 298 299 |
# File 'lib/graphql/query.rb', line 297 def selected_operation with_prepared_ast { @selected_operation } end |