Method: GraphQL::Schema::Argument#loads
- Defined in:
- lib/graphql/schema/argument.rb
#loads ⇒ Class, ... (readonly)
Returns If this argument should load an application object, this is the type of object to load.
32 33 34 |
# File 'lib/graphql/schema/argument.rb', line 32 def loads @loads end |