Method: GraphQL::Schema::FieldExtension#after_resolve
- Defined in:
- lib/graphql/schema/field_extension.rb
#after_resolve(object:, arguments:, context:, value:, memo:) ⇒ Object
Called after #field was resolved, and after any lazy values (like Promises) were synced,
but before the value was added to the GraphQL response.
Whatever this hook returns will be used as the return value.
148 149 150 |
# File 'lib/graphql/schema/field_extension.rb', line 148 def after_resolve(object:, arguments:, context:, value:, memo:) value end |