Method: GraphQL::Schema::Warden#loadable?
- Defined in:
- lib/graphql/schema/warden.rb
#loadable?(type, _ctx) ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns True if this type is used for loads: but not in the schema otherwise and not explicitly hidden.
234 235 236 237 238 |
# File 'lib/graphql/schema/warden.rb', line 234 def loadable?(type, _ctx) visible_type?(type) && !referenced?(type) && (type.respond_to?(:interfaces) ? interfaces(type).all? { |i| loadable?(i, _ctx) } : true) end |