Method: GraphQL::Schema::Wrapper#of_type
- Defined in:
- lib/graphql/schema/wrapper.rb
#of_type ⇒ Class, Module (readonly)
Returns The inner type of this wrapping type, the type of which one or more objects may be present.
9 10 11 |
# File 'lib/graphql/schema/wrapper.rb', line 9 def of_type @of_type end |