Class: GraphQL::Query
- Inherits:
-
Object
- Object
- GraphQL::Query
- Defined in:
- lib/graphql/query.rb,
lib/graphql/query/context.rb,
lib/graphql/query/executor.rb,
lib/graphql/query/arguments.rb,
lib/graphql/query/variables.rb,
lib/graphql/query/literal_input.rb,
lib/graphql/query/type_resolver.rb,
lib/graphql/query/serial_execution.rb,
lib/graphql/query/directive_resolution.rb,
lib/graphql/query/input_validation_result.rb,
lib/graphql/query/variable_validation_error.rb,
lib/graphql/query/serial_execution/field_resolution.rb,
lib/graphql/query/serial_execution/value_resolution.rb,
lib/graphql/query/serial_execution/execution_context.rb,
lib/graphql/query/serial_execution/operation_resolution.rb,
lib/graphql/query/serial_execution/selection_resolution.rb
Overview
Defined Under Namespace
Modules: DirectiveResolution Classes: Arguments, Context, Executor, InputValidationResult, LiteralInput, OperationNameMissingError, SerialExecution, TypeResolver, VariableValidationError, Variables
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
Returns the value of attribute context.
-
#debug ⇒ Object
readonly
Returns the value of attribute debug.
-
#document ⇒ Object
readonly
Returns the value of attribute document.
-
#fragments ⇒ Object
readonly
Returns the value of attribute fragments.
-
#max_depth ⇒ Object
readonly
Returns the value of attribute max_depth.
-
#operations ⇒ Object
readonly
Returns the value of attribute operations.
-
#root_value ⇒ Object
readonly
Returns the value of attribute root_value.
-
#schema ⇒ Object
readonly
Returns the value of attribute schema.
Instance Method Summary collapse
-
#initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, debug: nil, validate: true, operation_name: nil, root_value: nil, max_depth: nil) ⇒ Query
constructor
Prepare query
query_stringonschema. -
#result ⇒ Object
Get the result for this query, executing it once.
-
#selected_operation ⇒ GraphQL::Language::Nodes::OperationDefinition?
This is the operation to run for this query.
-
#variables ⇒ GraphQL::Query::Variables
Determine the values for variables of this query, using default values if a value isn't provided at runtime.
Constructor Details
#initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, debug: nil, validate: true, operation_name: nil, root_value: nil, max_depth: nil) ⇒ Query
Prepare query query_string on schema
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/graphql/query.rb', line 22 def initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, debug: nil, validate: true, operation_name: nil, root_value: nil, max_depth: nil) fail ArgumentError, "a query string or document is required" unless query_string || document @schema = schema if debug == false warn("Muffling errors with `debug: false` is deprecated and will be removed. For a similar behavior, use `MySchema.middleware << GraphQL::Schema::CatchallMiddleware`.") elsif debug == true warn("`debug:` will be removed from a future GraphQL version (and raising errors will be the default behavior, like `debug: true`)") end @debug = debug || false @max_depth = max_depth || schema.max_depth @context = Context.new(query: self, values: context) @root_value = root_value @validate = validate @operation_name = operation_name @fragments = {} @operations = {} @provided_variables = variables @document = document || GraphQL.parse(query_string) @document.definitions.each do |part| if part.is_a?(GraphQL::Language::Nodes::FragmentDefinition) @fragments[part.name] = part elsif part.is_a?(GraphQL::Language::Nodes::OperationDefinition) @operations[part.name] = part end end end |
Instance Attribute Details
#context ⇒ Object (readonly)
Returns the value of attribute context.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def context @context end |
#debug ⇒ Object (readonly)
Returns the value of attribute debug.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def debug @debug end |
#document ⇒ Object (readonly)
Returns the value of attribute document.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def document @document end |
#fragments ⇒ Object (readonly)
Returns the value of attribute fragments.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def fragments @fragments end |
#max_depth ⇒ Object (readonly)
Returns the value of attribute max_depth.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def max_depth @max_depth end |
#operations ⇒ Object (readonly)
Returns the value of attribute operations.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def operations @operations end |
#root_value ⇒ Object (readonly)
Returns the value of attribute root_value.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def root_value @root_value end |
#schema ⇒ Object (readonly)
Returns the value of attribute schema.
11 12 13 |
# File 'lib/graphql/query.rb', line 11 def schema @schema end |
Instance Method Details
#result ⇒ Object
Get the result for this query, executing it once
53 54 55 56 57 58 59 |
# File 'lib/graphql/query.rb', line 53 def result if @validate && validation_errors.any? return { "errors" => validation_errors } end @result ||= Executor.new(self).result end |
#selected_operation ⇒ GraphQL::Language::Nodes::OperationDefinition?
This is the operation to run for this query. If more than one operation is present, it must be named at runtime.
65 66 67 |
# File 'lib/graphql/query.rb', line 65 def selected_operation @selected_operation ||= find_operation(@operations, @operation_name) end |
#variables ⇒ GraphQL::Query::Variables
Determine the values for variables of this query, using default values if a value isn't provided at runtime.
Raises if a non-null variable isn't provided at runtime.
74 75 76 77 78 79 80 |
# File 'lib/graphql/query.rb', line 74 def variables @variables ||= GraphQL::Query::Variables.new( schema, selected_operation.variables, @provided_variables ) end |