Method: GraphQL::Query#initialize

Defined in:
lib/graphql/query.rb

#initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, validate: true, operation_name: nil, root_value: nil, max_depth: nil, max_complexity: nil, except: NullExcept) ⇒ Query

Prepare query query_string on schema

Parameters:

  • schema (GraphQL::Schema)
  • query_string (String) (defaults to: nil)
  • context (#[]) (defaults to: nil)

    an arbitrary hash of values which you can access in Field#resolve

  • variables (Hash) (defaults to: {})

    values for $variables in the query

  • operation_name (String) (defaults to: nil)

    if the query string contains many operations, this is the one which should be executed

  • root_value (Object) (defaults to: nil)

    the object used to resolve fields on the root type

  • max_depth (Numeric) (defaults to: nil)

    the maximum number of nested selections allowed for this query (falls back to schema-level value)

  • max_complexity (Numeric) (defaults to: nil)

    the maximum field complexity for this query (falls back to schema-level value)

  • except (<#call(schema_member)>) (defaults to: NullExcept)

    If provided, objects will be hidden from the schema when .call(schema_member) returns truthy



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/graphql/query.rb', line 40

def initialize(schema, query_string = nil, document: nil, context: nil, variables: {}, validate: true, operation_name: nil, root_value: nil, max_depth: nil, max_complexity: nil, except: NullExcept)
  fail ArgumentError, "a query string or document is required" unless query_string || document

  @schema = schema
  @warden = GraphQL::Schema::Warden.new(schema, except)
  @max_depth = max_depth || schema.max_depth
  @max_complexity = max_complexity || schema.max_complexity
  @query_analyzers = schema.query_analyzers.dup
  if @max_depth
    @query_analyzers << GraphQL::Analysis::MaxQueryDepth.new(@max_depth)
  end
  if @max_complexity
    @query_analyzers << GraphQL::Analysis::MaxQueryComplexity.new(@max_complexity)
  end
  @context = Context.new(query: self, values: context)
  @root_value = root_value
  @operation_name = operation_name
  @fragments = {}
  @operations = {}
  @provided_variables = variables
  @query_string = query_string
  @document = document || GraphQL.parse(query_string)
  @document.definitions.each do |part|
    if part.is_a?(GraphQL::Language::Nodes::FragmentDefinition)
      @fragments[part.name] = part
    elsif part.is_a?(GraphQL::Language::Nodes::OperationDefinition)
      @operations[part.name] = part
    else
      raise GraphQL::ExecutionError, "GraphQL query cannot contain a schema definition"
    end
  end

  @arguments_cache = Hash.new { |h, k| h[k] = {} }
  @validation_errors = []
  @analysis_errors = []
  @internal_representation = nil
  @was_validated = false

  # Trying to execute a document
  # with no operations returns an empty hash
  @ast_variables = []
  if @operations.any?
    @selected_operation = find_operation(@operations, @operation_name)
    if @selected_operation.nil?
      @validation_errors << GraphQL::Query::OperationNameMissingError.new(@operations.keys)
    else
      @ast_variables = @selected_operation.variables
    end
  end
end