Method: GraphQL::Query#initialize

Defined in:
lib/graphql/query.rb

#initialize(schema, query_string, context: nil, variables: {}, debug: false, validate: true, operation_name: nil) ⇒ Query

Prepare query query_string on schema

Parameters:

  • schema (GraphQL::Schema)
  • query_string (String)
  • context (#[]) (defaults to: nil)

    an arbitrary hash of values which you can access in Field#resolve

  • variables (Hash) (defaults to: {})

    values for ‘$variables` in the query

  • debug (Boolean) (defaults to: false)

    if true, errors are raised, if false, errors are put in the errors key

  • validate (Boolean) (defaults to: true)

    if true, query_string will be validated with StaticValidation::Validator

  • operation_name (String) (defaults to: nil)

    if the query string contains many operations, this is the one which should be executed



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/graphql/query.rb', line 16

def initialize(schema, query_string, context: nil, variables: {}, debug: false, validate: true, operation_name: nil)
  @schema = schema
  @debug = debug
  @context = Context.new(values: context)

  @variables = variables
  @validate = validate
  @operation_name = operation_name
  @fragments = {}
  @operations = {}

  @document = GraphQL.parse(query_string)
  @document.parts.each do |part|
    if part.is_a?(GraphQL::Language::Nodes::FragmentDefinition)
      @fragments[part.name] = part
    elsif part.is_a?(GraphQL::Language::Nodes::OperationDefinition)
      @operations[part.name] = part
    end
  end
end