Method: GraphQL::Schema.parse_error

Defined in:
lib/graphql/schema.rb

.parse_error(parse_err, ctx) ⇒ Object

A function to call when #execute receives an invalid query string

The default is to add the error to context.errors

Parameters:

  • The error encountered during parsing

  • The context for the query where the error occurred

Returns:

  • void



1059
1060
1061
# File 'lib/graphql/schema.rb', line 1059

def parse_error(parse_err, ctx)
  ctx.errors.push(parse_err)
end